@@ -12,4 +12,8 @@ extern crate serde;
 #[macro_use]
 extern crate serde_json;
 
-pub mod client;
\ No newline at end of file
+#[cfg(feature = "default")]
+pub mod client;
+
+#[cfg(feature = "async")]
+pub mod async_client;
\ No newline at end of file
